@@ -1,7 +1,7 @@
 /*
  *
  * This file is part of the iText (R) project.
-    Copyright (c) 1998-2019 iText Group NV
+    Copyright (c) 1998-2020 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -51,6 +51,7 @@ import com.itextpdf.text.Phrase;
 import com.itextpdf.text.Rectangle;
 import com.itextpdf.text.pdf.events.FieldPositioningEvents;
 import junit.framework.Assert;
+import org.junit.BeforeClass;
 import org.junit.Test;
 
 import java.io.ByteArrayInputStream;
@@ -65,18 +66,18 @@ import java.io.OutputStream;
 import java.util.Map;
 import java.util.Set;
 
-/**
- * @author Michael Demey
- */
 public class FlatteningTest {
 
     private static final String RESOURCES_FOLDER = "./src/test/resources/com/itextpdf/text/pdf/FlatteningTest/";
     private static final String OUTPUT_FOLDER = "./target/com/itextpdf/test/pdf/FlatteningTest/";
 
+    @BeforeClass
+    public static void setUp() {
+        new File(OUTPUT_FOLDER).mkdirs();
+    }
+
     @Test
     public void testFlatteningNewAppearances() throws InterruptedException, DocumentException, IOException {
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "tpl3_flattened.pdf";
 
         PdfReader reader = new PdfReader(RESOURCES_FOLDER + "tpl3.pdf");
@@ -107,7 +108,6 @@ public class FlatteningTest {
 
     @Test
     public void flattenGenerateAppearanceFalse01() throws IOException, DocumentException, InterruptedException {
-
         String outFile = OUTPUT_FOLDER + "flattenGenerateAppearanceFalse01.pdf";
         FileOutputStream file = new FileOutputStream(outFile);
         PdfReader reader = new PdfReader(new FileInputStream(RESOURCES_FOLDER + "not_filled_form.pdf"));
@@ -141,8 +141,6 @@ public class FlatteningTest {
         if (!inputFolder.exists())
             Assert.fail("Input folder can't be found (" + INPUT_FOLDER + ")");
 
-        new File(OUTPUT_FOLDER).mkdirs();
-
         String[] files = inputFolder.list(new FilenameFilter() {
             public boolean accept(File dir, String name) {
                 return name.endsWith(".pdf");
@@ -167,9 +165,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances1() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "noappearances-needapp-false_override-false.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "noappearances-needapp-false.pdf", OUTPUT_FOLDER + OUT, false);
 
@@ -182,9 +177,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances2() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "noappearances-needapp-false_override-true.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "noappearances-needapp-false.pdf", OUTPUT_FOLDER + OUT, true);
 
@@ -197,9 +189,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances3() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "noappearances-needapp-false_override-none.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "noappearances-needapp-false.pdf", OUTPUT_FOLDER + OUT, null);
 
@@ -212,9 +201,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances4() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "noappearances-needapp-true_override-false.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "noappearances-needapp-true.pdf", OUTPUT_FOLDER + OUT, false);
 
@@ -227,9 +213,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances5() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "noappearances-needapp-true_override-true.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "noappearances-needapp-true.pdf", OUTPUT_FOLDER + OUT, true);
 
@@ -242,9 +225,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances6() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "noappearances-needapp-true_override-none.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "noappearances-needapp-true.pdf", OUTPUT_FOLDER + OUT, null);
 
@@ -257,9 +237,6 @@ public class FlatteningTest {
 
     @Test
     public void testFlatteningGenerateAppearances7() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         final String OUT = "test01.pdf";
         testFlatteningGenerateAppearance(RESOURCES_FOLDER + "test01.pdf", OUTPUT_FOLDER + OUT, true);
 
@@ -281,9 +258,6 @@ public class FlatteningTest {
 
     @Test
     public void testRegeneratingFieldsFalse() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         String file = "regenerateField_false.pdf";
 
         Document doc = new Document(PageSize.A4);
@@ -332,9 +306,6 @@ public class FlatteningTest {
 
     @Test
     public void testRegeneratingFieldsTrue() throws IOException, DocumentException, InterruptedException {
-
-        new File(OUTPUT_FOLDER).mkdirs();
-
         String file = "regenerateField_true.pdf";
 
         Document doc = new Document(PageSize.A4);
@@ -383,8 +354,6 @@ public class FlatteningTest {
 
     @Test
     public void testAnnotationFlatteningWithSkewAndRotation() throws IOException, DocumentException, InterruptedException {
-        new File(OUTPUT_FOLDER).mkdirs();
-
         String file = "annotationWithTransformMatrix.pdf";
         PdfReader reader = new PdfReader(RESOURCES_FOLDER + file);
         PdfStamper stamper = new PdfStamper(reader, new FileOutputStream(OUTPUT_FOLDER + file));
@@ -401,8 +370,6 @@ public class FlatteningTest {
 
     @Test
     public void testRotatedFilledField() throws IOException, DocumentException, InterruptedException {
-        new File(OUTPUT_FOLDER).mkdirs();
-
         String file = "rotatedField.pdf";
         PdfReader pdfReader = new PdfReader(RESOURCES_FOLDER + file);
         PdfStamper pdfStamper = new PdfStamper(pdfReader, new FileOutputStream(OUTPUT_FOLDER + file));
@@ -423,8 +390,6 @@ public class FlatteningTest {
     }
     @Test
     public void testFreeTextRectangleBBoxInteraction() throws IOException, DocumentException, InterruptedException {
-        new File(OUTPUT_FOLDER).mkdirs();
-
         String file = "freeTextRectangleBBoxInteraction.pdf";
         PdfReader pdfReader = new PdfReader(RESOURCES_FOLDER + file);
         PdfStamper pdfStamper = new PdfStamper(pdfReader, new FileOutputStream(OUTPUT_FOLDER + file));
